/*****************************************************
*
*	GPS_watch.h
*
*	For GPS_watch.c
*	- includes required libraries for code to run
*	- defines constants
*
*****************************************************/


#include "shared.h"
#include <math.h>
#include "lcd_lib.h" 

/* GPS watch libraries */
#include "scheduler.h"
#include "tasks.h"
#include "buttons.h"
#include "main.h"
#include "gps.h"
#include "uart1.h"

/**********************
* Constants           *
**********************/

/* Main Menu states */
#define NAVIGATE 1
#define STAT 2
#define OPTIONS 3

/* Button numbers */
#define LEFT 3
#define RIGHT 2
#define SELECT 1
#define BACK 4

#define MAX_ROUTES 100 // Maximum number of routes to store on card
#define MAX_WAYPTS 20	// Max number of waypoints for a route

/* Navigation Constants */
// Distance (m) from waypoint at which to advance to next waypoint
#define NEAR_DIST 20
// Distance (m) from waypoint to give constant motor indications
#define INIT_DIST 25
#define TURN_IND 90		// Degrees from correct bearing to indicate correction

/* EEPROM Addresses */
#define EEPROM_DIST 8 	// EEPROM address to store accumulated distance
#define EEPROM_TIME 16 	// EEPROM address to store accumulated run time
#define EEPROM_SAVE 0	// EEPROM address to indicate saved state

/* Array of loaded route's waypoints */
double waypt_long[MAX_WAYPTS];
double waypt_lat[MAX_WAYPTS];

/* GPS Position structure */
Position raw;

/* List of available routes on SD card */
char route_list[MAX_ROUTES][14];
/* Number of routes on SD card */
uint8_t num_routes;

/* Name of currently opened log file */
char log_name[14];
/* Main menu state (selection) */
uint8_t menu_selection;

/* Statistics */
double total_dist;
double total_time;
