/****************************************************
*													*
*	buttons.c 										*
*													*
*	Debounce state machine for UI buttons			*
*													*
****************************************************/

#define TRUE 1
#define FALSE 0

#include "buttons.h"

uint8_t current_button;
uint8_t debounce_state = 1;
/* States */
#define RELEASED 1
#define MAYBE 2
#define PRESSED 3
#define MAYBE_REL 4

/* Returns the currently pressed button or highest 
	priority button if multiple pressed: high to low
	back (4), select (3), right (2), left (1) */
void get_button(void){
	uint8_t inv_PINA = ~PINA;// Buttons active low
	if(inv_PINA & 8){// back pressed (PIN A.3)
		current_button = 4;
	} else if(inv_PINA & 4){ // select pressed (PIN A.2)
		current_button = 3;
	} else if(inv_PINA & 2){ // right pressed (PIN A.1)
		current_button = 2;
	} else if(inv_PINA & 1){ // left pressed (PIN A.0)
		current_button = 1;
	} else { // nothing pressed
		current_button = 0;
	}
}

void debounce(void){
	get_button();
	switch (debounce_state){
		case RELEASED:
			if(current_button != 0) {
				debounce_state = MAYBE;
				butnum = current_button;
			}
		break;
		case MAYBE:
			if(current_button == butnum){
				debounce_state = PRESSED;
				button_flag = TRUE;
			} else { debounce_state = RELEASED; }
		break;
		case PRESSED:
			if (current_button == 0) {
				debounce_state = MAYBE_REL;
			}
		break;
		case MAYBE_REL:
			if (current_button == 0) {
				debounce_state = RELEASED;
			}
		break;
	}
}
